@@ -54,7 +54,7 @@ var TabbrowserPopupController = {
 			window.openBrowserTab = this.openBrowserTab;
 			window.shouldOpenBrowserTab = this.shouldOpenBrowserTab;
 			if (window.openDialog) {
-				window.__tabextensions_ctrlpopup__openDialog = window.openDialog;
+				window.__tabextensions_ctrlpopup__openDialog = (window.openDialog.toString().indexOf('[native code]') > -1) ? Components.lookupMethod(window, 'openDialog') : window.openDialog ;
 				window.openDialog = this.newOpenDialog;
 			}
 		}
@@ -64,6 +64,8 @@ var TabbrowserPopupController = {
 		if ('gPopupBlockerObserver' in window && gPopupBlockerObserver) {
 			gPopupBlockerObserver.__tabextensions_ctrlpopup__showBlockedPopup = gPopupBlockerObserver.showBlockedPopup;
 			gPopupBlockerObserver.showBlockedPopup = this.showBlockedPopup;
+			if (!gPopupBlockerObserver._findChildShell && window.findChildShell)
+				gPopupBlockerObserver._findChildShell = this.callFindChildShell;
 		}
 
 
@@ -366,15 +368,7 @@ if (TS.debug) dump('   allowed\n');
 			return window;
 		}
 
-		var args = [];
-		for (var i = 0; i < arguments.length; i++)
-			args.push('arguments['+i+']');
-
-/*
-		window.childWindows.push(eval('__tabextensions_ctrlpopup__openDialog('+args.join(', ')+')'));
-		return window.childWindows[window.childWindows.length-1];
-*/
-		return eval('__tabextensions_ctrlpopup__openDialog('+args.join(', ')+')');
+		return __tabextensions_ctrlpopup__openDialog.apply(this, arguments);
 	},
  
 	// methods like "GlobalWindowImpl", transplanted from nsGlobalWindow.cpp 
@@ -646,7 +640,7 @@ if (TS.debug) dump('   allowed\n');
 			w.__tabextensions_ctrlpopup__popupState = popupState;
 			try {
 				if (typeof exp == 'function')
-					eval('exp('+args+')');
+					exp.apply(w, args);
 				else
 					eval(exp);
 			}
@@ -698,7 +692,7 @@ if (TS.debug) dump('   allowed\n');
 			w.__tabextensions_ctrlpopup__popupState = popupState;
 			try {
 				if (typeof exp == 'function')
-					eval('exp('+args+')');
+					exp.apply(w, args);
 				else
 					eval(exp);
 			}
@@ -922,8 +916,12 @@ if (TS.debug) dump('   allowed\n');
 
 		w = new XPCNativeWrapper(t.mBrowser.contentWindow,
 				'opener',
-				'name'
+				'name',
+				'document'
 			);
+		var safeDocument = new XPCNativeWrapper(w.document);
+		w.document = safeDocument;
+		delete safeDocument;
 
 		w.opener = aContextWindow;
 		if (
@@ -1081,11 +1079,17 @@ if (TS.debug) dump('   allowed\n');
                           .getService(Components.interfaces.nsIIOService)
                           .newURI(aEvent.target.getAttribute('requestingWindowURI'), null, null);
 		var shell = this._findChildShell(gBrowser.selectedBrowser.docShell, requestingWindowURI);
-		if (!shell) return;
-
-		shell.QueryInterface(Components.interfaces.nsIInterfaceRequestor).getInterface(Components.interfaces.nsIDOMWindowInternal).__tabextensions__LastEvent = (new Date()).getTime();
+		if (shell) {
+			shell.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+				.getInterface(Components.interfaces.nsIDOMWindowInternal)
+				.__tabextensions__LastEvent = (new Date()).getTime();
+		}
 
 		this.__tabextensions_ctrlpopup__showBlockedPopup(aEvent);
+	},
+	callFindChildShell : function(aDocShell, aSoughtURI)
+	{
+		return findChildShell(null, aDocShell, aSoughtURI);
 	}
  
 }; 
