@@ -52,15 +52,16 @@ var TBEBrowserService =
 			window.addEventListener('blur', this.onWindowBlur, true);
 
 			TS.addPrefListener(gTSTabbarBlankSpacePrefListener);
+			TS.addPrefListener(gTSNarrowTabPrefListener);
 			TS.addPrefListener(gTSCloseBoxPrefListener);
 			TS.addPrefListener(gTSLastTabClosingPrefListener);
 			TS.addPrefListener(gTSTabsAutoHidePrefListener);
 			TS.addPrefListener(gTSIconOverlayInTabsPrefListener);
 			TS.addPrefListener(gTSTabbarPlacePrefListener);
 			TS.addPrefListener(gTSGroupModePrefListener);
+			TS.addPrefListener(gTSThumbnailPrefListener);
 			TS.addPrefListener(gTSTabsWidthPrefListener);
 			TS.addPrefListener(gTSTabScrollerPrefListener);
-			TS.addPrefListener(gTSAnotherBindingPrefListener);
 
 			window.addEventListener('resize', this.onWindowResize, false);
 		}
@@ -69,21 +70,24 @@ var TBEBrowserService =
 
 		if (TS.isBrowserWindow) {
 			gTSTabMenuPrefListener.observe(null, 'nsPref:changed', null);
+			gTSProgressbarPrefListener.observe(null, 'nsPref:changed', null);
 			gTSPlatformNativeBehaviorPrefListener.observe(null, 'nsPref:changed', null);
 			gTWindowModePrefListener.observe(null, 'nsPref:changed', null);
+			gTSGroupModePrefListener.observe(null, 'nsPref:changed', null);
 		}
 		if (TS.browser) {
 			gTSTabbarPlacePrefListener.update();
 //			gTSTabbarPlacePrefListener.observe(null, 'nsPref:changed', null);
 			gTSIconOverlayInTabsPrefListener.observe(null, 'nsPref:changed', null);
 			gTSTabbarBlankSpacePrefListener.observe(null, 'nsPref:changed', null);
+			gTSNarrowTabPrefListener.observe(null, 'nsPref:changed', null);
 			gTSCloseBoxPrefListener.observe(null, 'nsPref:changed', 'browser.tabs.extensions.show_closebox.tab');
 			gTSCloseBoxPrefListener.observe(null, 'nsPref:changed', 'browser.tabs.extensions.show_closebox.tabbar');
 			gTSCloseBoxPrefListener.observe(null, 'nsPref:changed', 'browser.tabs.extensions.show_closebox.tab.appearance');
 			gTSLastTabClosingPrefListener.observe(null, 'nsPref:changed', null);
+			gTSThumbnailPrefListener.observe(null, 'nsPref:changed', null);
 			gTSTabsWidthPrefListener.observe(null, 'nsPref:changed', null);
 			gTSTabScrollerPrefListener.observe(null, 'nsPref:changed', null);
-			gTSAnotherBindingPrefListener.observe(null, 'nsPref:changed', null);
 
 			var defaultFeaturePrefs = [
 					'locked',
@@ -96,7 +100,8 @@ var TBEBrowserService =
 				];
 			var j;
 			var t = TS.browser.mTabs;
-			for (i = 0; i < t.length; i++)
+			var max = t.length;
+			for (i = 0; i < max; i++)
 				for (j in defaultFeaturePrefs)
 					t[i][defaultFeaturePrefs[j]] = TS.getPref('browser.tabs.extensions.'+defaultFeaturePrefs[j]+'.enabled');
 		}
@@ -118,7 +123,8 @@ var TBEBrowserService =
 			function resetTabIndex()
 			{
 				var tabs = b.mTabs;
-				for (var i = 0; i < tabs.length; i++)
+				var max  = tabs.length;
+				for (var i = 0; i < max; i++)
 					tabs[i].tabIndex = i;
 			}
 			resetTabIndex();
@@ -146,6 +152,7 @@ var TBEBrowserService =
 
 		if (TS.isBrowserWindow) {
 			TS.removePrefListener(gTSTabMenuPrefListener);
+			TS.removePrefListener(gTSProgressbarPrefListener);
 			TS.removePrefListener(gTSPlatformNativeBehaviorPrefListener);
 			TS.removePrefListener(gTWindowModePrefListener);
 			TS.removePrefListener(gTSOpenTabForWindowOpenPrefListener);
@@ -166,6 +173,7 @@ var TBEBrowserService =
 			window.removeEventListener('blur', this.onWindowBlur, true);
 
 			TS.removePrefListener(gTSTabbarBlankSpacePrefListener);
+			TS.removePrefListener(gTSNarrowTabPrefListener);
 			TS.removePrefListener(gTSCloseBoxPrefListener);
 			TS.removePrefListener(gTSLastTabClosingPrefListener);
 			TS.removePrefListener(gTSTabsAutoHidePrefListener);
@@ -174,7 +182,6 @@ var TBEBrowserService =
 			TS.removePrefListener(gTSGroupModePrefListener);
 			TS.removePrefListener(gTSTabsWidthPrefListener);
 			TS.removePrefListener(gTSTabScrollerPrefListener);
-			TS.removePrefListener(gTSAnotherBindingPrefListener);
 
 			window.removeEventListener('resize', this.onWindowResize, false);
 		}
@@ -396,6 +403,13 @@ var TBEBrowserService =
 		}
 	},
  
+	onXULTabbrowserTabbarResized : function(aEvent) 
+	{
+		var TS = TabbrowserService;
+		var b  = TS.browser;
+		TS.setPref('browser.tabs.extensions.tabs_width', b.mStrip.boxObject.width);
+	},
+ 
 	onXULTabbrowserTabLoading : function(aEvent) 
 	{
 		TBEBrowserService.onTabLoading(aEvent.target.getTabByTabId(aEvent.tabId), aEvent.loadingView, !aEvent.followFrames);
@@ -463,7 +477,8 @@ var TBEBrowserService =
 		var max      = TS.getPref('browser.tabs.extensions.limit.number');
 		var info,
 			b        = TS.browserWindows;
-		for (var i = 0; i < b.length; i++)
+		var max = b.length;
+		for (var i = 0; i < max; i++)
 		{
 			if (
 				b[i] == window ||
@@ -496,25 +511,23 @@ var TBEBrowserService =
 	{
 		var TS = TabbrowserService;
 
+		var id = aRelatedTab.tabId;
+
 		if (aWindow == Components.lookupMethod(aWindow, 'top').call(aWindow) &&
 			!('__tabextensions__initialized' in aWindow)) {
 			// ACRw肳ĂꍇÃACRD悷B
 			// URIACRw肳ꂽubN}[NURI艺ʂ̃fBNgłȂꍇAACRZbgB
 			var icon = TS.getIconForBookmark(aRelatedTab.getAttribute('tab-loadingURI'), true);
-			if (icon) {
-				window.setTimeout(
-					function(aTab, aURI)
-					{
-						aTab.setAttribute('image', aURI);
-						// y[WJ_ŃACȐ񂪏㏑Ă܂Ă̂ŁAēx㏑
-					},
-					0,
-					aRelatedTab, icon
-				);
+			if (icon && id) {
+				window.setTimeout('TabbrowserService.browser.getTabByTabId("'+id+'").setAttribute("image", "'+icon+'");', 0);
+				// y[WJ_ŃACȐ񂪏㏑Ă܂Ă̂ŁAēx㏑
 				TS.setIconForBookmark(aRelatedTab.getAttribute('tab-loadingURI'));
 			}
 		}
 
+		if (id)
+			window.setTimeout('TabbrowserService.browser.getTabByTabId("'+id+'").updateThumbnail();', 0);
+
 		var frames;
 		try {
 			frames = Components.lookupMethod(aWindow, 'frames').call(aWindow);
@@ -522,7 +535,8 @@ var TBEBrowserService =
 		catch(e) {
 		}
 		if (frames && !aShouldNotFollowFrames) {
-			for (var i = 0; i < frames.length; i++)
+			var max = frames.length;
+			for (var i = 0; i < max; i++)
 				this.onTabLoading(aRelatedTab, frames[i]);
 		}
 
@@ -634,7 +648,7 @@ var TBEBrowserService =
 				)
 			);
 		}
-		// fix the problem: when tabs are rearranged the URL bar indicates "not-rearranged" URLs. (only in Mozilla Suite)
+		// fix the problem: when tabs are rearranged the URL bar indicates "not-rearranged" URLs. (only in Firefox 1.0.x / Mozilla Suite)
 		updateCurrentBrowser = b.updateCurrentBrowser.toString();
 		if (updateCurrentBrowser.search(/this\.mPanelContainer\.childNodes\[.+\.selectedIndex\]/) > -1) {
 			eval('b.updateCurrentBrowser = '+
@@ -644,6 +658,34 @@ var TBEBrowserService =
 				)
 			);
 		}
+		else if (updateCurrentBrowser.search(/this\.mPanelContainer\.selectedIndex/) > -1) {
+			eval('b.updateCurrentBrowser = '+
+				updateCurrentBrowser.replace(
+					/this\.mPanelContainer\.selectedIndex/g,
+					'this.mTabContainer.selectedIndex'
+				)
+			);
+		}
+
+
+
+
+		/* Tab Bar Splitter */
+
+		var splitter = document.createElement('splitter');
+		splitter.setAttribute('tabid', 'tabbar-splitter');
+
+		splitter.mTabBrowser = b;
+		splitter.setAttribute('onmouseup', [
+			'var event = document.createEvent("Events");',
+			'event.initEvent("XULTabbrowserTabbarResized", false, true);',
+			'this.mTabBrowser.dispatchEvent(event);'
+		].join(''));
+
+		b.mStrip.parentNode.insertBefore(splitter, b.mStrip.nextSibling);
+		b.mTabBarSplitter = splitter;
+
+		b.addEventListener('XULTabbrowserTabbarResized', this.onXULTabbrowserTabbarResized, false);
 	},
 	
 	// \bh̏㏑ 
@@ -660,10 +702,16 @@ var TBEBrowserService =
 		aTabBrowser.removeTab = this.removeTab;
 
 
+		aTabBrowser.__tabextensions__setStripVisibilityTo = aTabBrowser.setStripVisibilityTo;
+		aTabBrowser.setStripVisibilityTo = this.setStripVisibilityTo;
+
 
 		aTabBrowser.replaceGroup = this.replaceGroup;
 
-		aTabBrowser.getBrowserForTab = this.getBrowserForTab;
+		aTabBrowser.getBrowserForTab           = this.getBrowserForTab;
+		aTabBrowser.getBrowserAtIndex          = this.getBrowserAtIndex;
+		aTabBrowser.getBrowserIndexForDocument = this.getBrowserIndexForDocument;
+
 		aTabBrowser.onTabClick       = this.onTabClick;
 		aTabBrowser.flipCurrentTab   = this.flipCurrentTab;
 
@@ -683,7 +731,8 @@ var TBEBrowserService =
 		aTabBrowser.updatePopupMenu = this.updatePopupMenu;
 
 		var popups = aTabBrowser.mStrip.getElementsByAttribute('onpopupshowing', '*');
-		for (var i = 0; i < popups.length; i++)
+		var max = popups.length;
+		for (var i = 0; i < max; i++)
 			if (popups[i].localName == 'menupopup') {
 				popups[i].setAttribute('onpopupshowing', 'this.parentNode.parentNode.parentNode.updatePopupMenu(this, event);');
 				popups[i].mTabBrowser = aTabBrowser;
@@ -780,6 +829,23 @@ var TBEBrowserService =
 		return null;
 	},
  
+	getBrowserAtIndex : function(aIndex) 
+	{
+		return (aIndex < this.mTabs.length) ? this.mTabs[aIndex].mBrowser : null ;
+	},
+ 
+	getBrowserIndexForDocument : function(aDocument) 
+	{
+		var tabs = this.mTabs;
+		var max = tabs.length;
+		for (var i = 0; i < max; i++) {
+			if (tabs[i].mBrowser.contentDocument == aDocument) {
+				return i;
+			}
+		}
+		return -1;
+	},
+ 
 	// |bvAbvj[̍XV 
 	updatePopupMenu : function(aPopup, aEvent)
 	{
@@ -809,7 +875,8 @@ var TBEBrowserService =
 
 		var nodes = aPopup.getElementsByAttribute('tbattr', 'tabbrowser-multiple');
 		var single = gBrowser.mTabs.length == 1 ;
-		for (var i = 0;i < nodes.length; i++)
+		var max = nodes.length;
+		for (var i = 0;i < max; i++)
 			if (single)
 				nodes[i].setAttribute('disabled', true);
 			else
@@ -898,8 +965,12 @@ var TBEBrowserService =
 		}
 
 		var type = (aEvent.type == 'dblclick') ? (aEvent.button == 0 ? 'double' : null ) :
-					(aEvent.button == 1 || (aEvent.button == 0 && (aEvent.ctrlKey || aEvent.metaKey))) ? 'middle' :
+					(aEvent.button == 1) ? 'middle' :
 					(aEvent.button == 2) ? 'right' :
+					(aEvent.button != 0) ? null :
+					(!aEvent.shiftKey && (aEvent.ctrlKey || aEvent.metaKey) && !aEvent.altKey) ? 'ctrl' :
+					(aEvent.shiftKey && !aEvent.ctrlKey && !aEvent.metaKey && !aEvent.altKey) ? 'shift' :
+					(!aEvent.shiftKey && !aEvent.ctrlKey && !aEvent.metaKey && aEvent.altKey) ? 'alt' :
 					null ;
 
 		if (!type) return;
@@ -930,15 +1001,8 @@ var TBEBrowserService =
 						pref = 'ondblclick';
 						break;
 
-					case 'middle':
-						pref = 'onmiddleclick';
-						break;
-
-					case 'right':
-						pref = 'onrightclick';
-						break;
-
 					default:
+						pref = 'on'+type+'click';
 						break;
 				}
 				break;
@@ -951,15 +1015,8 @@ var TBEBrowserService =
 						pref = 'tabbar_ondblclick';
 						break;
 
-					case 'middle':
-						pref = 'tabbar_onmiddleclick';
-						break;
-
-					case 'right':
-						pref = 'tabbar_onrightclick';
-						break;
-
 					default:
+						pref = 'tabbar_on'+type+'click';
 						break;
 				}
 				break;
@@ -1089,6 +1146,11 @@ var TBEBrowserService =
 			case 302:
 				this.toggleAllTabsAutoReload();
 				break;
+
+			case 400:
+				if (tab.hasChildTabs())
+					tab.tabSubgroupCollapsed = !tab.tabSubgroupCollapsed;
+				break;
 		}
 
 		aEvent.preventDefault();
@@ -1103,17 +1165,29 @@ var TBEBrowserService =
 		this.advanceSelectedTabByLastFocusedTime(-1);
 	},
  
+	setStripVisibilityTo : function(aValue) 
+	{
+		if (aValue)
+			this.removeAttribute('tabbar-hidden');
+		else
+			this.setAttribute('tabbar-hidden', true);
+
+		this.__tabextensions__setStripVisibilityTo(aValue);
+	},
+ 
 	replaceGroup : function(aGroupInfo) 
 	{
 		var oldTabsInfo = [];
 		var i;
 
-		for (i = 0; i < this.mTabs.length; i++)
+		var max = this.mTabs.length;
+		for (i = 0; i < max; i++)
 			oldTabsInfo.push(this.getTabInfo(this.mTabs[i]));
 
 		var t = this.removeAllTabsButInternal(this.addTab('about:blank'), { preventUndo : true });
 
-		for (i = 0; i < aGroupInfo.length; i++)
+		max = aGroupInfo.length;
+		for (i = 0; i < max; i++)
 		{
 			if ('SHEntries' in aGroupInfo[i])
 				this.addTabWithTabInfo(aGroupInfo[i]);
@@ -1140,7 +1214,7 @@ var TBEBrowserService =
 	updateContextMenu : function(aTabBrowser)
 	{
 	try {
-		var i;
+		var i, max;
 		var TS = TabbrowserService;
 		var mpopup = aTabBrowser.mTabContainer.previousSibling;
 
@@ -1170,7 +1244,8 @@ var TBEBrowserService =
 			res,
 			id,
 			namedItems = [];
-		for (i = 0; i < mpopup.childNodes.length; i++)
+		max = mpopup.childNodes.length;
+		for (i = 0; i < max; i++)
 		{
 			label = mpopup.childNodes[i].getAttribute('label');
 			if (!label) continue;
@@ -1231,7 +1306,8 @@ var TBEBrowserService =
 				'removeTab',     'removeOneTab',
 				'reloadAll',     'reload' // for old context menu
 			];
-		for (i = 0; i < separators.length; i += 2)
+		max = separators.length;
+		for (i = 0; i < max; i += 2)
 		{
 			if (
 				!(separators[i] in namedItems) ||
@@ -1522,6 +1598,19 @@ var TBEBrowserService =
 
 		this.insertNewItemBefore(mpopup, 'menuseparator', null, null, ['tabid', 'tab-sep-group']);
 
+
+		// Tuc[̊J
+		// collapse/expand subgroup
+		this.insertNewItemBefore(
+			mpopup, 'menuitem',
+			'label_collapseExpandGroup', null,
+			[
+				'oncommand', 'var b = this.parentNode.mTabBrowser; var t = b.mContextTab; if (t.hasChildTabs()) t.tabSubgroupCollapsed = !t.tabSubgroupCollapsed;',
+				'tabid', 'tab-item-collapseExpandGroup',
+				'tbattr', 'tabbrowser-tree'
+			]
+		);
+
 		// ^uׂ̕
 		// sort tabs
 		this.insertNewItemBefore(
@@ -1598,9 +1687,11 @@ var TBEBrowserService =
 
 		if (aLabelID)
 			newItem.setAttribute('label', TabbrowserService.strbundle.GetStringFromName(aLabelID));
-		if (aAttrArray)
-			for (var i = 0; i < aAttrArray.length; i += 2)
+		if (aAttrArray) {
+			var max = aAttrArray.length;
+			for (var i = 0; i < max; i += 2)
 				newItem.setAttribute(aAttrArray[i], aAttrArray[i+1]);
+		}
 
 		return newItem;
 	},
@@ -1608,6 +1699,7 @@ var TBEBrowserService =
 	// tabs̃Abvf[g 
 	updateTabContainer : function(aTabBrowser)
 	{
+		var i, max;
 		// initialize the order of tabs, "new tab" and "close tab" button.
 		/* Content of tabs:
 			Mozilla 1.1+
@@ -1667,7 +1759,8 @@ try{
 
 		var tabContents = aTabBrowser.mTabContainerInnerBox.childNodes;
 		var isAfter = false;
-		for (i = 0; i < tabContents.length; i++)
+		max = tabContents.length;
+		for (i = 0; i < max; i++)
 		{
 			if (tabContents[i].localName == 'tab') {
 				isAfter = true;
@@ -1702,7 +1795,7 @@ catch(e) {
 		// add properties and methods without XBL
 		container.mTabBrowser        = aTabBrowser;
 		container.advanceSelectedTab = this.advanceSelectedTab;
-		if (!('selectNewTab' in container))
+//		if (!('selectNewTab' in container))
 			container.selectNewTab = this.selectNewTab;
 
 
@@ -1728,12 +1821,9 @@ catch(e) {
 		var startTab = this.selectedItem;
 		var tabs     = b.mTabs;
 
-		var nextIndex = startTab.tabIndex+aDir;
-		if (nextIndex < 0) nextIndex = tabs.length-1;
-		if (nextIndex > tabs.length-1) nextIndex = 0;
-
-		var next = tabs[nextIndex];
-
+		var next = (aDir < 0) ?
+			(startTab.previousTab || tabs[tabs.length-1]) :
+			(startTab.nextTab || tabs[0]) ;
 		if (next && next != startTab)
 			this.selectNewTab(next);
 
@@ -1746,17 +1836,24 @@ catch(e) {
  
 	selectNewTab : function(aNewTab) // Firefox 1.1 has this method but 1.0.x doesn't, so I emulate it. 
 	{
-		var isTabFocused = (document.commandDispatcher.focusedElement == this.selectedItem);
+		if (aNewTab.mTabButtonClicked) {
+			aNewTab.mTabButtonClicked = false;
+			return;
+		}
 
-		this.selectedItem = aNewTab;
+		var tabContainer = this.localName == 'tabbrowser' ? this.mTabContainer : this ;
+
+		var isTabFocused = (document.commandDispatcher.focusedElement == tabContainer.selectedItem);
+
+		tabContainer.selectedItem = aNewTab;
 
 		if (isTabFocused) {
 			aNewTab.focus();
-        }
-		else if (this.getAttribute('setfocus') != 'false') {
+		}
+		else if (tabContainer.getAttribute('setfocus') != 'false') {
 			aNewTab.focus();
 			document.commandDispatcher.advanceFocusIntoSubtree(aNewTab);
-			this.mTabBrowser.setFocusInternal();
+			tabContainer.mTabBrowser.setFocusInternal();
 		}
 	},
 	
@@ -1817,12 +1914,15 @@ catch(e) {
 		b.removeEventListener('click', this.emulateTabbarClick, true);
 		b.removeEventListener('dblclick', this.emulateTabbarClick, true);
 
+		b.removeEventListener('XULTabbrowserTabbarResized', this.onXULTabbrowserTabbarResized, false);
+
 
 		b.bookmarksManager = null;
 
 
 		var browser;
-		for (var i = 0; i < b.mTabs.length; i++)
+		var max = b.mTabs.length;
+		for (var i = 0; i < max; i++)
 		{
 			try {
 				browser = b.mTabs[i].mBrowser;
@@ -1955,9 +2055,9 @@ catch(e) {
 				uri = win.location.href;
 			}
 			catch(e) {
-				uri = 'about:blank';
+//				uri = 'about:blank';
 				if (TS.debug) dump('gTSDOMWindowOpenObserver.onObserve():: '+e+'\n');
-				return;
+//				return;
 			}
 
 			if (!uri) {
@@ -1965,6 +2065,8 @@ catch(e) {
 				return;
 			}
 
+			if (TS.debug) dump('gTSDOMWindowOpenObserver.onObserve():: loading '+uri+'\n');
+
 			if (uri != TS.browserURI) // this is not browser
 				return;
 
@@ -2089,6 +2191,25 @@ var gTSTabMenuPrefListener =
 	}
 };
  
+var gTSProgressbarPrefListener = 
+{
+	domain  : 'browser.tabs.extensions.show_progress',
+	observe : function(aSubject, aTopic, aPrefName)
+	{
+		if (aTopic != 'nsPref:changed' ||
+			!('TabbrowserService' in window)) return;
+
+		var isShown = !TabbrowserService.getPref('browser.tabs.extensions.show_progress.tab') || TabbrowserService.getPref('browser.tabs.extensions.show_progress.status');
+
+		var bar = document.getElementById('statusbar-progresspanel') || document.getElementById('statusbar-icon');
+		if (isShown)
+			bar.removeAttribute('tabextensions-progress-hidden');
+		else
+			bar.setAttribute('tabextensions-progress-hidden', true);
+
+	}
+};
+ 
 var gTSPlatformNativeBehaviorPrefListener = 
 {
 	domains : [
@@ -2227,7 +2348,7 @@ var gTWindowModePrefListener =
 
 		if (window.location.href != TS.browserURI) return;
 
-		var i;
+		var i, max;
 		var isSingleWindow = TS.winHookMode == 2 ? true : false ;
 
 		var items = [
@@ -2239,7 +2360,8 @@ var gTWindowModePrefListener =
 		// Firefox
 		if (TS.isNewTypeBrowser) {
 			var nodes = document.getElementsByAttribute('command', 'cmd_newNavigator');
-			for (i = 0; i < nodes.length; i++)
+			max = nodes.length;
+			for (i = 0; i < max; i++)
 				if (nodes[i].localName == 'menuitem')
 					items.push(nodes[i]);
 		}
@@ -2374,7 +2496,8 @@ var gTSIconOverlayInTabsPrefListener =
 
 		var shouldOverlay = TabbrowserService.getPref(this.domain);
 		var b = TabbrowserService.browser;
-		for (i = 0; i < b.mTabs.length; i++)
+		var max = b.mTabs.length;
+		for (i = 0; i < max; i++)
 			b.mTabs[i].setAttribute('overlay-icon', shouldOverlay);
 	}
 };
@@ -2393,9 +2516,13 @@ var gTSTabsWidthPrefListener =
 		if (aTopic != 'nsPref:changed') return;
 
 		var b = TabbrowserService.browser;
-		for (var i = 0; i < b.mTabs.length; i++)
+		var max = b.mTabs.length;
+		for (var i = 0; i < max; i++)
 			b.mTabs[i].initTab();
 
+		if (b.mTabBox.orient == 'horizontal')
+			b.mStrip.setAttribute('width', TabbrowserService.getPref('browser.tabs.extensions.tabs_width'));
+
 		b.onTabsModified();
 	}
 };
@@ -2411,6 +2538,20 @@ var gTSTabbarBlankSpacePrefListener =
 	}
 };
  
+var gTSNarrowTabPrefListener = 
+{
+	domain  : 'browser.tabs.extensions.vertical.narrow_tabs',
+	observe : function(aSubject, aTopic, aPrefName)
+	{
+		if (aTopic != 'nsPref:changed') return;
+
+		if (TabbrowserService.getPref(this.domain))
+			TabbrowserService.browser.setAttribute('tab-tree-narrow-tab', true);
+		else
+			TabbrowserService.browser.removeAttribute('tab-tree-narrow-tab');
+	}
+};
+ 
 var gTSLastTabClosingPrefListener = 
 {
 	domain  : 'browser.tabs.extensions.last_tab_closing',
@@ -2474,6 +2615,9 @@ var gTSTabbarPlacePrefListener =
 			)
 			return;
 
+		if (place < 2)
+			TS.setPref('browser.tabs.extensions.group.tree.enabled', false);
+
 		if (aPreventToUpdateNow) {
 			if (TS.PromptService.confirm(
 					window,
@@ -2496,7 +2640,8 @@ var gTSTabbarPlacePrefListener =
 
 		var attr = place < 2 ? 'label-for-horizontal-tabbar' : 'label-for-vertical-tabbar' ;
 		var nodes = document.getElementsByAttribute(attr, '*');
-		for (var i = 0; i < nodes.length; i++)
+		var max = nodes.length;
+		for (var i = 0; i < max; i++)
 			nodes[i].setAttribute('label', nodes[i].getAttribute(attr));
 	}
 };
@@ -2505,19 +2650,66 @@ var gTSTabbarPlacePrefListener =
 // clear the relation of tabs when the TabGroup Mode is disabled
 var gTSGroupModePrefListener =
 {
-	domain  : 'browser.tabs.extensions.group.enabled',
+	domains : [
+		'browser.tabs.extensions.group.enabled',
+		'browser.tabs.extensions.group.tree.enabled'
+	],
 	observe : function(aSubject, aTopic, aPrefName)
 	{
-		if (aTopic != 'nsPref:changed' ||
-			TabbrowserService.getPref(this.domain)) return;
+		if (aTopic != 'nsPref:changed') return;
 
 		var b = TabbrowserService.browser;
-		for (i = 0; i < b.mTabs.length; i++)
-		{
-			b.mTabs[i].parentTab = null;
-			b.mTabs[i].removeAttribute('tab-childTabs');
-			b.mTabs[i].removeAttribute('tab-openedAutomatically');
-			b.mTabs[i].removeAttribute('tab-groupTargetHost');
+		var max = b.mTabs.length;
+		var i;
+
+		var groupMode = TabbrowserService.getPref('browser.tabs.extensions.group.enabled');
+		if (!groupMode) {
+			for (i = 0; i < max; i++)
+			{
+				b.mTabs[i].parentTab = null;
+				b.mTabs[i].removeAttribute('tab-childTabs');
+				b.mTabs[i].removeAttribute('tab-openedAutomatically');
+				b.mTabs[i].removeAttribute('tab-groupTargetHost');
+			}
+			TabbrowserService.setPref('browser.tabs.extensions.group.tree.enabled', false);
+		}
+
+		var treeMode  = TabbrowserService.getPref('browser.tabs.extensions.group.tree.enabled');
+		if (groupMode && treeMode) {
+			b.setAttribute('tab-tree-enabled', true);
+			var place = TabbrowserService.getPref('browser.tabs.extensions.tabbar_place');
+			if (place > 1)
+				b.updateTabTree();
+			else
+				TabbrowserService.setPref('browser.tabs.extensions.tabbar_place', 2);
+		}
+		else {
+			b.removeAttribute('tab-tree-enabled');
+			b.updateTabTree(true);
+		}
+	}
+};
+ 
+var gTSThumbnailPrefListener = 
+{
+	domains : [
+		'browser.tabs.extensions.thumbnail.enabled',
+		'browser.tabs.extensions.thumbnail.width',
+		'browser.tabs.extensions.thumbnail.height',
+		'browser.tabs.extensions.thumbnail.power'
+	],
+	observe : function(aSubject, aTopic, aPrefName)
+	{
+		if (aTopic != 'nsPref:changed') return;
+
+		var b = TabbrowserService.browser;
+		if (TabbrowserService.getPref('browser.tabs.extensions.thumbnail.enabled')) {
+			b.setAttribute('tab-thumbnail-enabled', true);
+			for (var i = 0, max = b.mTabs.length; i < max; i++)
+				b.mTabs[i].updateThumbnail();
+		}
+		else {
+			b.removeAttribute('tab-thumbnail-enabled');
 		}
 	}
 };
@@ -2567,20 +2759,6 @@ var gTSTabScrollerPrefListener =
 		TS.browser.setAttribute('tab-scrollbar', value);
 	}
 };
- 
-var gTSAnotherBindingPrefListener = 
-{
-	domain  : 'browser.tabs.extensions.use_another_binding',
-	observe : function(aSubject, aTopic, aPrefName)
-	{
-		if (aTopic != 'nsPref:changed') return;
-
-		if (TabbrowserService.getPref(this.domain))
-			document.documentElement.setAttribute('tabextensions-another-binding', 'true');
-		else
-			document.documentElement.removeAttribute('tabextensions-another-binding');
-	}
-};
   
 // initializing: failsafe 
 if (
