@@ -160,7 +160,8 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 		if (b.selectedTab.getAttribute('tab-loadingURI') == aLinkInfo.uri)
 			return true;
 
-		for (var i = 0; i < b.mTabs.length; i++)
+		var max = b.mTabs.length;
+		for (var i = 0; i < max; i++)
 		{
 			if (b.mTabs[i].getAttribute('tab-loadingURI') != aLinkInfo.uri)
 				continue;
@@ -230,7 +231,6 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 
 		aLinkInfo.behavior = -1;
 
-
 		// middle click
 		aLinkInfo.newTabActionMiddleClick = (
 				aEvent.type == 'click' &&
@@ -268,7 +268,7 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 				!this.service.getFrameByName(topWin, aLinkInfo.target)
 			);
 		if  (aLinkInfo.newTabActionTarget && aLinkInfo.behavior < 0) {
-			aLinkInfo.behavior = this.service.getPref('browser.tabs.opentabfor.links.targetBehavior');
+				aLinkInfo.behavior = this.service.getPref('browser.tabs.opentabfor.links.targetBehavior');
 			if (aLinkInfo.behavior < 0 && this.service.winHookMode > 0)
 				aLinkInfo.behavior = this.service.loadInBackground ? 2 : 1 ;
 		}
@@ -300,6 +300,53 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 			aLinkInfo.newTabActionNormalClick = (aLinkInfo.behavior > 0);
 		}
 
+		// block URIs end with some extensions or patterns
+		aLinkInfo.newTabActionBlockedURI = this.service.getPref('browser.tabs.opentabfor.links.block_uri.type');
+		aLinkInfo.newTabActionBlockedURI = (aLinkInfo.newTabActionBlockedURI == 2) ||
+					(
+						aLinkInfo.newTabActionBlockedURI == 1 &&
+						!aLinkInfo.newTabActionNormalClick &&
+						!aLinkInfo.newTabActionMiddleClick &&
+						aLinkInfo.behavior != 0
+					);
+		if (aLinkInfo.newTabActionBlockedURI) {
+			var uri  = aLinkInfo.uri;
+			var rule = (this.service.getPref('browser.tabs.opentabfor.links.block_uri.rule') || '').toLowerCase().split(/[ \n\r]+/);
+
+			var uriForExtension = uri.substring(uri.lastIndexOf('/'), uri.length);
+			uriForExtension = uriForExtension.substring(uriForExtension.indexOf('.'), uriForExtension.length);
+
+			var testRegExp = new RegExp();
+			var uri_ext;
+			var max = rule.length;
+			for (i = 0; i < max; i++)
+			{
+/*
+				if (node.hasAttribute('onclick') &&
+					(node.getAttribute('onclick').indexOf(('return install')||('return installTheme')) == 0))
+					return true;
+*/
+				try{
+					if (rule[i].indexOf('/') < 0) {
+						testRegExp = testRegExp.compile('\\.'+rule[i], 'i');
+						uri_ext    = uriForExtension;
+					}
+					else {
+						testRegExp = testRegExp.compile(rule[i].substring(1, rule[i].length-1), 'i');
+						uri_ext    = uri;
+					}
+				}
+				catch(e) {
+					continue;
+				}
+
+				if (testRegExp.test(uri_ext)) {
+					aLinkInfo.behavior = 0;
+					break;
+				}
+			}
+		}
+
 		if (aLinkInfo.behavior < 0)
 			aLinkInfo.behavior = 0;
 
@@ -399,8 +446,16 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 		if (
 			aLinkInfo.normalClickAction &&
 			aLinkInfo.newTabActionNormalClick &&
-			!aLinkInfo.realTarget &&
-			topWin != aLinkInfo.window
+			(
+				(
+					!aLinkInfo.realTarget &&
+					topWin != aLinkInfo.window
+				) ||
+				(
+					aLinkInfo.target &&
+					this.service.getFrameByName(topWin, aLinkInfo.target)
+				)
+			)
 			) {
 			if (!aLinkInfo.referrerBlocked)
 				return __tabextensions__contentAreaClick(aEvent, aLinkInfo.fieldNormalClicks);
@@ -410,6 +465,7 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 			return true;
 		}
 
+
 		var postData = {};
 		var convertedURI = ('getShortcutOrURI' in window) ? getShortcutOrURI(uri, postData) : uri ; // in Mail&Newsgroup, "getShortcutOrURI()" is not defined!!
 		postData = 'value' in postData ? postData.value : null ;
@@ -433,7 +489,8 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 			) {
 			var browser;
 			var contentWindow;
-			for (i = 0; i < b.mTabs.length; i++)
+			var max = b.mTabs.length;
+			for (i = 0; i < max; i++)
 			{
 				browser = b.mTabs[i].mBrowser;
 				contentWindow = new XPCNativeWrapper(browser.contentWindow,
@@ -568,7 +625,8 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 			// add the tab to the children list
 			if (
 				b.tabGroupsAvailable &&
-				b.ownerDocument == document // reject tabs opened by undocked sidebar and so on
+				b.ownerDocument == document && // reject tabs opened by undocked sidebar and so on
+				this.service.getOwnerBrowserFromNode(node) == this.service.browser
 				) {
 				info.parentTab = aLinkInfo.tabId;
 				info.openedAutomatically = aLinkInfo.causedByTargetAttribute || aLinkInfo.causedByLocked || aLinkInfo.causedByAlwaysNewTab ;
@@ -638,9 +696,12 @@ catch(e) { if (TS.debug) dump('contentAreaClick => doLinkAction:\n'+e+'\n'); }
 	messagePaneOnClick : function(aEvent) 
 	{
 		// ignore simple click, because new browser has been opened by customized contentAreaClick().
-		var uri = hrefForClickEvent(aEvent);
-		if (uri &&
-			uri.search(/^(https?|ftp|file|gopher|chrome|resource|about):/i) > -1 &&
+		var res = ('hrefAndLinkNodeForClickEvent' in window) ? hrefAndLinkNodeForClickEvent(aEvent) : { href : hrefForClickEvent(aEvent) };
+		// hrefAndLinkNodeForClickEvent is for lately SeaMonkey.
+		// hrefForClickEvent is for old Mozilla.
+		if (res &&
+			res.href &&
+			res.href.search(/^(https?|ftp|file|gopher|chrome|resource|about):/i) > -1 &&
 			aEvent.button == 0 &&
 			!aEvent.metaKey &&
 			!aEvent.ctrlKey &&
