@@ -18,7 +18,8 @@ var TBEMovableTabService =
 		var b = this.service.browser;
 		if (!b) return;
 
-		if (!document.getElementById('tab-drop-indicator-bar'))
+		if (!document.getElementById('tab-drop-indicator-bar') &&
+			!document.getAnonymousElementByAttribute(b, 'class', 'tab-drop-indicator'))
 			this.createTabDropIndicator(b);
 
 		this.service.addPrefListener(gTSTabDropIndicatorTypePrefListener);
@@ -33,6 +34,9 @@ var TBEMovableTabService =
 
 		this.supportMovableTabs(b);
 
+		b.addEventListener('mousemove', this.onTabbrowserMouseMove, false);
+		b.addEventListener('mouseup',   this.onTabbrowserMouseUp, false);
+
 		gTSTabDropIndicatorTypePrefListener.observe(null, 'nsPref:changed', null);
 	},
 
@@ -43,6 +47,8 @@ var TBEMovableTabService =
 
 		this.service.removePrefListener(gTSTabDropIndicatorTypePrefListener);
 
+		b.removeEventListener('mousemove', this.onTabbrowserMouseMove, false);
+		b.removeEventListener('mouseup',   this.onTabbrowserMouseUp, false);
 		b.removeEventListener('XULTabbrowserTabDrop', this.onXULTabbrowserTabDrop, false);
 	},
 
@@ -52,9 +58,11 @@ var TBEMovableTabService =
 	{
 		var bar = document.createElement('hbox');
 		bar.setAttribute('tabid', 'tab-drop-indicator-bar');
+		bar.setAttribute('class', 'tab-drop-indicator-bar');
 
 		var indicator = document.createElement('hbox');
 		indicator.setAttribute('tabid', 'tab-drop-indicator');
+		indicator.setAttribute('class', 'tab-drop-indicator');
 
 		bar.appendChild(indicator);
 		aTabBrowser.mTabBox.appendChild(bar);
@@ -79,7 +87,8 @@ var TBEMovableTabService =
 			aTabBrowser.__defineGetter__('browsers',
 				function() {
 					var browsers = [];
-					for (var i = 0; i < this.mTabs.length; i++)
+					var max = this.mTabs.length;
+					for (var i = 0; i < max; i++)
 						browsers.push(this.getBrowserForTab(this.mTabs[i]));
 					return browsers;
 				}
@@ -261,6 +270,8 @@ var TBEMovableTabService =
 
 		aTabBrowser.__tabextensions__getSupportedFlavours = aTabBrowser.getSupportedFlavours;
 		aTabBrowser.getSupportedFlavours = this.getTabsSupportedFlavours;
+
+//		aTabBrowser.mDragOverFocusTimeout = this.mDragOverFocusTimeout;
 	},
  
 	onXULTabbrowserTabDrop : function(aEvent) 
@@ -270,8 +281,21 @@ var TBEMovableTabService =
 
 
  
-	getTabDropPosition : function(aEvent) 
+	getTabDropPosition : function(aEvent, aIndexObj) 
 	{
+		if (!aIndexObj)
+			aIndexObj = {};
+
+		var tab = aEvent.target;
+		if (this.tabGroupTreeAvailable &&
+			tab &&
+			this.mDraggedTab &&
+			this.mDraggedTab.parentTab != tab.parentTab) {
+			aIndexObj.value = aEvent.target.tabIndex;
+			return TBEMovableTabService.DROP_ON;
+		}
+
+
 		var isSimpleEdit = false;
 		try {
 			isSimpleEdit = this.mPrefs.getBoolPref('browser.tabs.extensions.group.edit_simple_dragdrop');
@@ -306,13 +330,22 @@ var TBEMovableTabService =
 		if (this.mScrollbar) // see "updateScrollbarFromEvent" in tabextensions.xml
 			coordValue -= Number(this.mScrollbar.getAttribute('curpos'));
 
-		if (clientCoordValue < (coordValue + measure)) // BEFORE
-			return current + (reversed ? 1 : 0 );
+		var retVal;
+
+		if (clientCoordValue < (coordValue + measure)) { // BEFORE
+			retVal = TBEMovableTabService.DROP_BEFORE;
+			aIndexObj.value = current + (reversed ? 1 : 0 );
+		}
 		else if (!this.tabGroupsAvailable ||
-				clientCoordValue >= (coordValue + (regionCount-1)*measure)) // AFTER
-			return current + (reversed ? 0 : 1 );
-		else
-			return -1;
+				clientCoordValue >= (coordValue + (regionCount-1)*measure)) { // AFTER
+			retVal = TBEMovableTabService.DROP_AFTER;
+			aIndexObj.value = current + (reversed ? 0 : 1 );
+		}
+		else {
+			retVal = TBEMovableTabService.DROP_ON;
+			aIndexObj.value = current;
+		}
+		return retVal;
 	},
 
 
@@ -325,10 +358,26 @@ var TBEMovableTabService =
 
 		var tab = this.getTabFromChild(aEvent.originalTarget);
 
-		// dragging tabbar
-		if (!tab) {
+
+		if (tab && tab.isEventFiredOn(aEvent, 'closebox')) {
+			TabbrowserService.stopEvent(aEvent);
+			this.mTabsReadyToClose = true;
+			tab.setAttribute('tab-ready-to-close', true);
 			return;
 		}
+		else if (
+			!tab || // dragging tabbar
+			(
+				!tab.isEventFiredOn(aEvent, 'favicon') &&
+				this.mPrefs.getBoolPref('browser.tabs.extensions.focus_with_drag')
+			)
+			) {
+			TabbrowserService.stopEvent(aEvent);
+			this.mTabsReadyToFocus = true;
+			return;
+		}
+
+
 
 		this.mDraggedTab = tab;
 
@@ -398,7 +447,16 @@ var TBEMovableTabService =
 
 		// ^ũhbvʒu𒲂ׂ
 		// get the dropped position of the tab
-		var newIndex = this.getDropPosition(aEvent);
+		var indexObj = {};
+		var newIndex = this.getDropPosition(aEvent, indexObj);
+		if (aEvent.target.localName == 'tab' && newIndex == 0) {
+			pos = TBEMovableTabService.DROP_ON;
+		}
+		newIndex = Math.max(0, Math.min(this.mTabs.length-1, indexObj.value))
+		toTab    = this.mTabs[newIndex];
+
+		if (fromTab && newIndex > fromTab.tabIndex)
+			newIndex--;
 
 		var reversed = window.getComputedStyle(this.parentNode, null).direction != 'ltr';
 		var pos,
@@ -406,25 +464,19 @@ var TBEMovableTabService =
 		if (aEvent.target.localName == 'tab') {
 			toTab = aEvent.target;
 
-			if (newIndex < 0) {
-				pos = TBEMovableTabService.DROP_ON;
-			}
-			else {
+			if (pos != TBEMovableTabService.DROP_ON) {
 				if (reversed ? (newIndex > toTab.tabIndex) : (newIndex <= toTab.tabIndex))
 					pos = TBEMovableTabService.DROP_BEFORE;
 				else if (reversed ? (newIndex <= toTab.tabIndex) : (newIndex > toTab.tabIndex))
 					pos = TBEMovableTabService.DROP_AFTER;
 			}
-
-			if (newIndex == this.mTabs.length)
-				newIndex--;
-
-			if (newIndex > -1)
-				toTab = this.mTabs[newIndex];
 		}
 		else {
 			var box = this.mTabs[this.mTabs.length-1].boxObject;
-			if (aEvent.screenX >= box.screenX+box.width) {
+			if (this.mTabBox.orient == 'vertical' ?
+				(aEvent.screenX >= box.screenX+box.width) :
+				(aEvent.screenY >= box.screenY+box.height)
+				) {
 				newIndex = this.mTabs.length-1;
 				pos = TBEMovableTabService.DROP_AFTER;
 			}
@@ -432,11 +484,11 @@ var TBEMovableTabService =
 				newIndex = 0;
 				pos = TBEMovableTabService.DROP_BEFORE;
 			}
-
 			toTab = this.mTabs[newIndex];
 		}
 
 
+
 		event = document.createEvent('Events');
 		event.initEvent('XULTabbrowserTabDrop', false, true);
 
@@ -490,14 +542,15 @@ var TBEMovableTabService =
 				return;
 
 			try {
-				TS.uriSecurityCheck(uri, droppedSourceURI);
+				TS.uriSecurityCheck(uri, aEvent.droppedSourceURI);
 			}
 			catch(e) {
 				return;
 			}
 
 			// when dropped to an existing tab
-			if (pos == TBEMovableTabService.DROP_ON &&
+			if (!b.tabGroupTreeAvailable &&
+				pos == TBEMovableTabService.DROP_ON &&
 				toTab.getAttribute('tab-loadingURI') &&
 				toTab.getAttribute('tab-loadingURI') != 'about:blank' &&
 				aEvent.dragdropTarget.localName == 'tab' &&
@@ -540,7 +593,7 @@ var TBEMovableTabService =
 				) {
 				var targetTab = (b.mTabs.length < 3) ? b.mTabs[0] : toTab ;
 				if (targetTab.isReallyBlank) {
-					b.removeTabInternal(targetTab, { preventUndo : yes });
+					b.removeTabInternal(targetTab, { preventUndo : true });
 					if (toTab == targetTab) toTab = null;
 				}
 			}
@@ -562,31 +615,37 @@ var TBEMovableTabService =
 					)
 				)
 			)) {
+			if (b.tabGroupTreeAvailable) {
+				fromTab.parentTab = toTab;
+			}
+			else {
 // If there is 3 tabs A, B(child of A) and C(child of A), and you open new tab D from A, tabextensions appends D to it's group. Then it has three children B, C, and D.
 // But, D is not accessible when there is too many tabs. In bookmark groups or links opened from the context menu, D shouldn't be the brother of B and C. For example, if new tabs are shown at the right edge of groups, expected result is following: A, D(child of A), B and C(child of B).
-			if (toTab.hasChildTabs() &&
-				toTab.shouldPurgeChildren) {
-				var children  = toTab.childTabs;
-				var newParent = toTab.parentTab || children[0] ;
-				for (i = 0; i < children.length; i++)
-					b.attachTabTo(children[i], children[i] == newParent ? toTab.parentTab : newParent );
+				if (toTab.hasChildTabs() &&
+					toTab.shouldPurgeChildren) {
+					var children  = toTab.childTabs;
+					var newParent = toTab.parentTab || children[0] ;
+					for (i = 0; i < children.length; i++)
+						b.attachTabTo(children[i], children[i] == newParent ? toTab.parentTab : newParent );
 
-				toTab.shouldPurgeChildren     = false;
-				newParent.shouldPurgeChildren = true;
+					toTab.shouldPurgeChildren     = false;
+					newParent.shouldPurgeChildren = true;
+				}
+
+				b.moveTabToGroupEdge(fromTab, toTab);
+
+				fromTab.parentTab = toTab;
 			}
-
-			b.moveTabToGroupEdge(fromTab, toTab);
-
-			fromTab.parentTab = toTab;
 		}
 		else {
-			if (toIndex > fromTab.tabIndex)
-				toIndex += (pos < 0 ? -1 : 0 );
-			else if (!isSimpleEdit || toIndex < fromTab.tabIndex)
-				toIndex += (pos > 0 ? 1 : 0 );
-
-			if (toIndex >= 0 && toIndex < b.mTabs.length)
+			if (
+				toIndex > -1 &&
+				toIndex < b.mTabs.length
+				) {
 				b.moveTabTo(fromTab, toIndex);
+				if (b.tabGroupTreeAvailable)
+					b.updateTabTree();
+			}
 
 
 			// ^uȊȌꏊɃhbvꍇAO[v𔲂
@@ -599,9 +658,9 @@ var TBEMovableTabService =
 
 				// q̃^u^ủEɍĔzu
 				// move child tabs to right of the tab
-				var tabs = fromTab.allChildTabs;
+				var tabs = fromTab.descendantTabs;
 				for (i in tabs)
-					b.moveTabTo(tabs[i], fromTab.tabIndex+1);
+					b.moveTabToGroupEdge(tabs[i], fromTab);
 			}
 		}
 	},
@@ -614,6 +673,30 @@ var TBEMovableTabService =
 		this.updateScrollbarFromEvent(aEvent);
 
 
+/*
+		if (aEvent.target.localName == 'tab' &&
+			this.mPrefs.getBoolPref('browser.tabs.extensions.focus_with_dragover')) {
+			if (!aEvent.target.selected)
+				this.selectedTab = aEvent.target;
+//			if (this.mDragOverFocusTimer &&
+//				this.mDragOverFocusTarget &&
+//				this.mDragOverFocusTarget != aEvent.target.tabId) {
+//				window.clearTimeout(this.mDragOverFocusTimer);
+//				this.mDragOverFocusTarget = null;
+//				this.mDragOverFocusTimer = null;
+//			}
+//			if (!this.mDragOverFocusTimer) {
+//				this.mDragOverFocusTarget = aEvent.target.tabId;
+//				this.mDragOverFocusTimer = window.setTimeout(
+//					this.mDragOverFocusTimeout,
+//					Math.max(0, this.mPrefs.getIntPref('browser.tabs.extensions.focus_with_dragover.delay')),
+//					this
+//				);
+//			}
+		}
+*/
+
+
 		var XferDataSet = nsTransferable.get(
 				this.getSupportedFlavours(),
 				nsDragAndDrop.getDragData,
@@ -630,59 +713,14 @@ var TBEMovableTabService =
 				return;
 		}
 
-
-		// auto scroll
-		if (this.mScrollbar) {
-			var wait         = 80,
-				clientPos,
-				areaStartPos = 0,
-				areaSize     = 40,
-				waitPower    = 1,
-				maxPos;
-			var preventScroll;
-			if ( // multirow
-					this.getAttribute('tab-scrollbar') == 'multirow') {
-				if (this.getAttribute('tabbar-overflow') == 'true') {
-					clientPos    = aEvent.clientY;
-					maxPos       = this.mTabContainer.boxObject.height;
-					areaStartPos = this.mTabContainer.boxObject.y;
-					areaSize     = 15;
-					waitPower    = 0.5;
-				}
-				else
-					preventScroll = true;
-			}
-			else if (this.mTabBox.orient == 'horizontal') { // left or right
-				clientPos = aEvent.clientY;
-				maxPos    = this.mTabContainerInnerBox.boxObject.height;
-			}
-			else { // top or bottom
-				clientPos = aEvent.clientX;
-				maxPos    = this.mTabContainerInnerBox.boxObject.width;
-			}
-			if (!preventScroll) {
-				maxPos = areaStartPos + maxPos;
-				if (clientPos > areaStartPos && clientPos < areaStartPos+areaSize) {
-					if (clientPos < (areaSize*0.25))
-						wait = 10;
-					else if (clientPos < (areaSize*0.6))
-						wait = 40;
-					this.scrollTabbarWithDelay(-10, wait*waitPower);
-				}
-				else if (clientPos > maxPos-areaSize && clientPos < maxPos) {
-					if (clientPos > maxPos-(areaSize*0.25))
-						wait = 10;
-					else if (clientPos > maxPos-(areaSize*0.6))
-						wait = 40;
-					this.scrollTabbarWithDelay(10, wait*waitPower);
-				}
-			}
-		}
-
-		this.mCurrentDragOverTab = (aEvent.target.localName == 'tab') ? aEvent.target : null ;
+		this.mCurrentDragOverTab = (aEvent.target.localName == 'tab') ? aEvent.target.tabId : null ;
 		if (!this.mCurrentDragOverTab) return;
 
-		var tab = this.mCurrentDragOverTab;
+		var tab = this.getTabByTabId(this.mCurrentDragOverTab);
+
+
+
+		this.autoScrollTabbar(aEvent);
 
 
 
@@ -695,13 +733,14 @@ var TBEMovableTabService =
 		}
 
 
-		var newIndex = this.getDropPosition(aEvent);
+		var indexObj = {};
+		var newIndex = this.getDropPosition(aEvent, indexObj);
 		var reversed = window.getComputedStyle(this.parentNode, null).direction != 'ltr';
 
 		var indicatorBar = this.mTabDropIndicatorBar;
 		var indicator = this.mTabDropIndicator;
 
-		if (newIndex < 0) {
+		if (newIndex == TBEMovableTabService.DROP_ON) {
 			if (this.mDraggedTab &&
 				!this.canAttachTabTo(this.mDraggedTab, tab)) {
 				aSession.canDrop = false;
@@ -712,11 +751,13 @@ var TBEMovableTabService =
 				indicatorBar.setAttribute('dragging', 'false');
 		}
 		else {
-			if (reversed ? (newIndex > tab.tabIndex) : (newIndex <= tab.tabIndex))
+			if (newIndex == TBEMovableTabService.DROP_BEFORE)
 				tab.setAttribute('dragover-at', 'before');
-			else if (reversed ? (newIndex <= tab.tabIndex) : (newIndex > tab.tabIndex))
+			else
 				tab.setAttribute('dragover-at', 'after');
 
+			newIndex = indexObj.value;
+
 			if (indicatorBar &&
 				this.getAttribute('tab-drop-indicator-type') == 'default')
 				indicatorBar.setAttribute('dragging', true);
@@ -729,7 +770,7 @@ var TBEMovableTabService =
 			if (!isSide) {
 				// ̍s̓ł͂ȂAO̍s̍Ōɕ\
 				if (
-					newIndex != this.mTabs.length &&
+					newIndex < this.mTabs.length &&
 					newIndex > 0 &&
 					(
 						(this.mTabs[newIndex].boxObject.y - this.mTabs[newIndex-1].boxObject.y) > (this.mTabs[newIndex].boxObject.height/2)
@@ -825,16 +866,36 @@ var TBEMovableTabService =
 			indicator.setAttribute('style', styleRules.join(';'));
 		}
 	},
+/*
+	mDragOverFocusTimeout : function(aBrowser)
+	{
+		if (aBrowser.mDragOverFocusTarget) {
+			var tab = aBrowser.getTabByTabId(aBrowser.mDragOverFocusTarget);
+			if (!tab.selected)
+				aBrowser.selectedTab = tab;
+		}
+
+		aBrowser.mDragOverFocusTarget = null;
+		aBrowser.mDragOverFocusTimer = null;
+	},
+*/
  
 	// onDragExit 
 	onTabDragExit : function(aEvent, aSession)
 	{
 		if (this.mCurrentDragOverTab)
-			this.mCurrentDragOverTab.removeAttribute('dragover-at');
+			this.getTabByTabId(this.mCurrentDragOverTab).removeAttribute('dragover-at');
 
 		var indicatorBar = this.mTabDropIndicatorBar;
 		if (indicatorBar)
 			indicatorBar.setAttribute('dragging', 'false');
+/*
+		if (this.mDragOverFocusTimer) {
+			window.clearTimeout(this.mDragOverFocusTimer);
+			this.mDragOverFocusTarget = null;
+			this.mDragOverFocusTimer = null;
+		}
+*/
 	},
 
 
@@ -847,6 +908,51 @@ var TBEMovableTabService =
 		flavourSet.appendFlavour('text/unicode');
 		flavourSet.appendFlavour('application/x-moz-file', 'nsIFile');
 		return flavourSet;
+	},
+
+
+	onTabbrowserMouseMove : function(aEvent)
+	{
+		var b = TabbrowserService.browser;
+		if (b.mTabsReadyToClose ||
+			b.mTabsReadyToFocus) {
+			b.autoScrollTabbar(aEvent, true);
+		}
+	},
+
+
+	onTabbrowserMouseUp : function(aEvent)
+	{
+		var b = TabbrowserService.browser;
+
+		if (b.mTabsReadyToClose) {
+			var xpathResult = b.evaluateXPath(
+					'child::*[local-name() = "tab" and @tab-ready-to-close = "true"]',
+					b.mTabContainer
+				);
+			if (xpathResult && xpathResult.snapshotLength) {
+				var removeTab = !('warnAboutClosingTabs' in b) || b.warnAboutClosingTabs(false);
+
+				for (var i = 0, max = xpathResult.snapshotLength, node; i < max; i++)
+				{
+					node = xpathResult.snapshotItem(i);
+					node.removeAttribute('tab-ready-to-close');
+					if (removeTab)
+						b.removeTab(node);
+				}
+			}
+		}
+
+		b.mTabsReadyToClose = false;
+		b.mTabsReadyToFocus = false;
+
+/*
+		if (b.mDragOverFocusTimer) {
+			window.clearTimeout(b.mDragOverFocusTimer);
+			b.mDragOverFocusTarget = null;
+			b.mDragOverFocusTimer = null;
+		}
+*/
 	}
 
 }; 
