@@ -1,4 +1,4 @@
-var version     = '1.14.2005071301',
+var version     = '2.1.2006011402',
 	displayName = 'Tabbrowser Extensions',
 	appName     = 'tabextensions',
 	author      = 'SHIMODA Hiroshi',
@@ -6,6 +6,7 @@ var version     = '1.14.2005071301',
 	hasJLP      = true,
 	hasSkin     = true,
 	options     = [
+					'eventhandler',
 					'sessionManager',
 					'ctrlPopup'
 				];
@@ -67,11 +68,19 @@ else {
 
 
 		if ('options' in this && options.length) {
+			var confirmMessage;
 			for (i = 0; i < options.length; i++)
 			{
-				if (confirm(optionsMsg[options[i]])) {
+				confirmMessage = null;
+				try {
+					confirmMessage = optionsMsg[options[i]];
+				}
+				catch(e) {
+				}
+				if (!confirmMessage || confirm(optionsMsg[options[i]])) {
 					registerChrome(contentFlag, folder, 'content/'+options[i]+'/');
-					installedOptions.push(options[i]);
+					if (confirmMessage)
+						installedOptions.push(options[i]);
 				}
 			}
 		}
